use strict;
use warnings;
use lib '/usr/local/monitoring/collectd/lib/collectd/perl';
use Collectd qw( :all );
no warnings 'all';
# Refactored on 29 January 2015
# This Perl Module is the pping plugin for collectd
# Reads two lists produced by /usr/sbin/fping utility
# Unreachable servers list & reachable servers list
# Dispatches 0 or 1 values for Down or Up servers
# Notifications here are disabled to be  handled
# by the collectd threshold


# Plugin name
my $CFG_plugin_name = "pping";
my $plugin_type = "gauge";
my $failure_code = 1;
my $success_code = 0;

sub fping {
    my $ufilename =  "/root/text.txt" ; # Unreachable
    my $afilename =  "/root/atext.txt" ; # Alive
    open IN, '<', $ufilename or plugin_log (LOG_INFO, "$CFG_plugin_name plugin : can\'t locate " . $ufilename);
    my @managed_servers_list = <IN>;
    close IN;
    open AIN, '<', $afilename or plugin_log (LOG_INFO, "$CFG_plugin_name plugin : can\'t locate " . $afilename);
    my @managed_a_servers_list = <AIN>;
    close AIN;
    my $tm = time();
    my $list_size = $#managed_servers_list + 1 ;
    my $u_list_size = $#managed_a_servers_list + 1 ;
    # Check the Unreachable list
    foreach (@managed_servers_list) {
        chomp($_);
        my $ping_stat = ''; # `fping $_` ;
        my $HOST = $_;
        $HOST =~ s/\.sd-france\.net//gi;
        $HOST.chomp();
        chomp($ping_stat);
        my $p = {
            values => [$failure_code],
            time     => $tm,
            interval => plugin_get_interval (),
            host     => $HOST,
            plugin   => $CFG_plugin_name,
            type     => $plugin_type,
            plugin_instance => '',
            type_instance   => ''
        };
        plugin_dispatch_values ($p);
        my $v = {
            severity => NOTIF_FAILURE,
            time     => $tm,
            message  => $ping_stat,
            host     => $HOST,
            plugin   => $CFG_plugin_name,
            type     => 'ping_status',
            meta     => [ { name => 'num_of_servers', value => $list_size } ]
        };
        #plugin_dispatch_notification ($v);
    }
    # Check the Alive List
    foreach (@managed_a_servers_list) {
        chomp($_);
        my $ping_stat = '';
        my $HOST = $_;
        $HOST =~ s/\.sd-france\.net//gi;
        $HOST.chomp();
        chomp($ping_stat);
        my $v = {
            severity => NOTIF_OKAY,
            time     => $tm,
            message  => $ping_stat,
            host     => $HOST,
            plugin   => $CFG_plugin_name,
            type     => 'ping_status',
            meta     => [ { name => 'num_of_servers', value => $u_list_size } ]
        };
        #plugin_dispatch_notification ($v);
        my $p = {
            values => [$success_code],
            time     => $tm,
            interval => plugin_get_interval (),
            host     => $HOST,
            plugin   => $CFG_plugin_name,
            type     => $plugin_type,
            plugin_instance => '',
            type_instance   => ''
        };
        plugin_dispatch_values ($p);
    }
}

sub read_ping_stat {
    fping();
    return 1;
}
plugin_register(TYPE_READ, $CFG_plugin_name, "read_ping_stat");
1;

