#!/usr/bin/python
from __future__ import with_statement
import contextlib
import os
import collectd

# Verbose logging on/off. Override in config by specifying 'Verbose'.
VERBOSE_LOGGING = False

#Util functions
def FileCheck(path):
    try:
        # Checks
        if os.path.isdir(path + "/etc/test12"):
            if os.path.isfile(path + "/etc/test12/check_write.test"):  
                os.remove(path + "/etc/test12/check_write.test")
            os.removedirs(path + "/etc/test12")
        os.makedirs(path + "/etc/test12")
        f = open(path + "/etc/test12/check_write.test", 'w')
        f.write('THIS-FILE-IS-USED-BY-COLLECTD-TO-TEST-WRITE-ON-THIS-PARTITION\n')
        f.close()
        os.remove(path + "/etc/test12/check_write.test")
        os.removedirs(path + "/etc/test12")
        return 1
    except IOError:
        return 0
    except OSError:
        return 0

def dispatch_value(value, key, type, type_instance=None):
    """dispatch a value"""

    if not type_instance:
        type_instance = key

    log_verbose('Sending value: %s=%s' % (type_instance, value))

    val = collectd.Values(plugin='write_check')
    val.type = type
    val.type_instance = type_instance
    val.values = [value]
    val.dispatch()

def log_verbose(msg):
    if not VERBOSE_LOGGING:
        return
    collectd.info('write_check plugin [verbose]: %s' % msg)

def configure_callback(conf):
    """Receive configuration block"""
    global DEVICE, MOUNT_POINT, VERBOSE_LOGGING, FS_TYPE
    for node in conf.children:
        if node.key == 'VERBOSE_LOGGING':
            VERBOSE_LOGGING = bool(node.values[0])
        else:
            collectd.warning('inodes_info plugin: Unknown config key: %s.'
                             % node.key)
    log_verbose('Configured with VERBOSE_LOGGING=%s' % (VERBOSE_LOGGING))

#FIXME,get partition from conf or from /etc/fstab?
def read():
    log_verbose('Read callback called')
    with contextlib.closing(open('/etc/fstab')) as fp:
        for m in fp:
            if not m.startswith('#'):
                if not m.startswith('\n'):
                    val = m.split()
                    # send high-level values
                    dispatch_value(FileCheck(val[1]), val[1], 'gauge')

# register callbacks
collectd.register_config(configure_callback)
collectd.register_read(read)    

